
class ProductUsage:

    # def product_viewed(self
    #                    , username: str
    #                    , warehouse: str
    #                    , database: str
    #                    , role: str
    #                    ):

    pass


